==> littlewizard_1.1.3.orig.tar.gz: littlewizard-1.1.3/liblanguage/commandfor.cc <==
/*
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 */

 /* (C) Marcin Kwadrans <quar@vitea.pl> */

#include "include/support.h"
#include "include/command.h"
#include "include/message.h"

/* Te polecenie występowało w wersjach 1.0.x, teraz jest przestarzała */
/* This command was present in verisons 1.0.x, now is deprecated */

class LWCommandForDeprecated: public LWCommand {

gint counter;

void reset1 ()
{
	counter = 0;
}
	
LWValue *execute1 (LWContext *context, guint argc, LWValue *args[])
{
	g_return_val_if_fail (argc == 1, NULL);
	g_return_val_if_fail (context->instrPtr->next != NULL, NULL);	
	
	if (counter == args[0]->toInt()) {
		context->instrPtr = context->instrPtr->next->next;
		counter = 0;
	} else 
		counter++;

	return NULL;
}

gchar *getName (void)
{
	return "for";
}	

gchar *getHint ()
{
	return _("Repeat N times");
}

gboolean isLoop ()
{
	return TRUE;
}

void checkArgc (guint n)
{
	if (n != 1) 
		throw new LWMessage (LW_ERROR_WrongNumberOfArguments);
}

public:
LWCommandForDeprecated(): counter(0) {};

};

LWSymbol *new_LWCommandForDeprecated()
{
	return new LWCommandForDeprecated();
}

==> littlewizard_1.2.0~rc2.orig.tar.gz: littlewizard-1.2.0rc2/liblanguage/commandfor.cc <==
/*
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 */

 /* (C) Marcin Kwadrans <quar@vitea.pl> */

#include "include/support.h"
#include "include/command.h"
#include "include/message.h"

/* Te polecenie występowało w wersjach 1.0.x, teraz jest przestarzała */
/* This command was present in verisons 1.0.x, now is deprecated */

class LWCommandForDeprecated: public LWCommand {

gint counter;

void reset1 ()
{
	counter = 0;
}
	
LWValue *execute1 (LWContext *context, guint argc, LWValue *args[])
{
	g_return_val_if_fail (argc == 1, NULL);
	g_return_val_if_fail (context->instrPtr->next != NULL, NULL);	
	
	if (counter == args[0]->toInt()) {
		context->instrPtr = context->instrPtr->next->next;
		counter = 0;
	} else 
		counter++;

	return NULL;
}

const gchar *getName (void)
{
	return "for";
}	

gchar *getHint ()
{
	return _("Repeat N times");
}

gboolean isLoop ()
{
	return TRUE;
}

void checkArgument (guint n, LWValue *value)
{
	(void) n;
	
	if (FALSE == value->isVariable() && FALSE == value->checkRange())
			throw new LWMessage (LW_ERROR_NumberOutOfRange);
}
	
void checkArgc (guint n)
{
	if (n != 1) 
		throw new LWMessage (LW_ERROR_WrongNumberOfArguments);
}

public:
LWCommandForDeprecated(): counter(0) {};

};

LWSymbol *new_LWCommandForDeprecated()
{
	return new LWCommandForDeprecated();
}
